Learn R Programming

speakr (version 3.2.4)

praat_open: Open files with 'Praat'.

Description

It opens a file or list of files in the 'Praat' GUI.

Usage

praat_open(...)

Value

Nothing. Used for its side effects.

Arguments

...

A character vector with the path to the file. Include multiple vector arguments to open multiple files.

Examples

Run this code
if (FALSE) {
# Open a single file

script <- system.file("extdata", "get-formants.praat", package = "speakr")
praat_open(script)

# Open multiple files

wav <- system.file("extdata", "vowels.wav", package = "speakr")
tg <- system.file("extdata", "vowels.TextGrid", package = "speakr")
praat_open(wav, tg)
}

Run the code above in your browser using DataLab