Learn R Programming

speakr (version 3.2.4)

praat_run: Run a 'Praat' script.

Description

It runs a 'Praat' script, with optional arguments passed to the script.

Usage

praat_run(script, ..., capture = FALSE)

Value

If the 'Praat' script returns standard output this is returned as a character vector. Also, if the script has instructions to create files, these will be created.

Arguments

script

A character vector containing the script name.

...

List of arguments to be passed to the script.

capture

If set to TRUE, the standard output of the script (for example, from writeInfo) can be saved into a variable in R. If FALSE (the default) the output is logged to the console.

Examples

Run this code
if (FALSE) {
script <- system.file("extdata", "get-formants.praat", package = "speakr")

# Run get-formants.praat with argument "Hertz" and log to console.
praat_run(script, "Hertz")

# Run get-formants.praat with arguments and save in R variable.
library(readr)
formants <- praat_run(script, "Hertz", 0.03, capture = TRUE) %>%
  read_csv()
}

Run the code above in your browser using DataLab